@@ -26,7 +26,7 @@ import (
 
 	"knative.dev/eventing/pkg/apis/eventing"
 
-	"knative.dev/eventing/pkg/client/injection/reconciler/messaging/v1alpha1/inmemorychannel"
+	"knative.dev/eventing/pkg/client/injection/reconciler/messaging/v1beta1/inmemorychannel"
 
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -35,14 +35,14 @@ import (
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/client-go/kubernetes/scheme"
 	clientgotesting "k8s.io/client-go/testing"
-	eventingduckv1alpha1 "knative.dev/eventing/pkg/apis/duck/v1alpha1"
-	"knative.dev/eventing/pkg/apis/messaging/v1alpha1"
+	eventingduckv1beta1 "knative.dev/eventing/pkg/apis/duck/v1beta1"
+	"knative.dev/eventing/pkg/apis/messaging/v1beta1"
 	"knative.dev/eventing/pkg/reconciler/inmemorychannel/controller/resources"
 	. "knative.dev/eventing/pkg/reconciler/testing"
 	reconciletesting "knative.dev/eventing/pkg/reconciler/testing"
 	"knative.dev/eventing/pkg/utils"
 	"knative.dev/pkg/apis"
-	duckv1alpha1 "knative.dev/pkg/apis/duck/v1alpha1"
+	duckv1beta1 "knative.dev/pkg/apis/duck/v1beta1"
 	"knative.dev/pkg/configmap"
 	"knative.dev/pkg/controller"
 	"knative.dev/pkg/kmeta"
@@ -62,14 +62,14 @@ const (
 
 func init() {
 	// Add types to scheme
-	_ = v1alpha1.AddToScheme(scheme.Scheme)
-	_ = duckv1alpha1.AddToScheme(scheme.Scheme)
+	_ = v1beta1.AddToScheme(scheme.Scheme)
+	_ = duckv1beta1.AddToScheme(scheme.Scheme)
 }
 
 func TestAllCases(t *testing.T) {
 	imcKey := testNS + "/" + imcName
 
-	subscribers := []eventingduckv1alpha1.SubscriberSpec{{
+	subscribers := []eventingduckv1beta1.SubscriberSpec{{
 		UID:           "2f9b5e8e-deb6-11e8-9f32-f2801f1b9fd1",
 		Generation:    1,
 		SubscriberURI: apis.HTTP("call1"),
@@ -81,7 +81,7 @@ func TestAllCases(t *testing.T) {
 		ReplyURI:      apis.HTTP("sink2"),
 	}}
 
-	subscriberStatuses := []eventingduckv1alpha1.SubscriberStatus{{
+	subscriberStatuses := []eventingduckv1beta1.SubscriberStatus{{
 		UID:                "2f9b5e8e-deb6-11e8-9f32-f2801f1b9fd1",
 		ObservedGeneration: 1,
 		Ready:              "True",
@@ -104,20 +104,20 @@ func TestAllCases(t *testing.T) {
 			Name: "deleting",
 			Key:  imcKey,
 			Objects: []runtime.Object{
-				reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelDeleted)},
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelDeletedV1Beta1)},
 			WantErr: false,
 		}, {
 			Name: "deployment does not exist",
 			Key:  imcKey,
 			Objects: []runtime.Object{
-				reconciletesting.NewInMemoryChannel(imcName, testNS),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS),
 			},
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelDeploymentFailed("DispatcherDeploymentDoesNotExist", "Dispatcher Deployment does not exist")),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelDeploymentFailedV1Beta1("DispatcherDeploymentDoesNotExist", "Dispatcher Deployment does not exist")),
 			}},
 			WantEvents: []string{
 				Eventf(corev1.EventTypeWarning, "DispatcherDeploymentFailed", `Reconciling dispatcher Deployment failed with: deployment.apps "imc-dispatcher" not found`),
@@ -129,20 +129,20 @@ func TestAllCases(t *testing.T) {
 				makeFalseDeployment(),
 				makeService(),
 				makeReadyEndpoints(),
-				reconciletesting.NewInMemoryChannel(imcName, testNS),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS),
 			},
 			WantErr: false,
 			WantCreates: []runtime.Object{
-				makeChannelService(reconciletesting.NewInMemoryChannel(imcName, testNS)),
+				makeChannelService(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
 			},
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelDeploymentFailed("DispatcherDeploymentFalse", "The status of Dispatcher Deployment is False: Deployment Failed : Deployment Failed"),
-					reconciletesting.WithInMemoryChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelEndpointsReady(),
-					reconciletesting.WithInMemoryChannelChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelAddress(channelServiceAddress)),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelDeploymentFailedV1Beta1("DispatcherDeploymentFalse", "The status of Dispatcher Deployment is False: Deployment Failed : Deployment Failed"),
+					reconciletesting.WithInMemoryChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelEndpointsReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelAddressV1Beta1(channelServiceAddress)),
 			}},
 			WantEvents: []string{
 				Eventf(corev1.EventTypeNormal, "InMemoryChannelReconciled", `InMemoryChannel reconciled: "test-namespace/test-imc"`),
@@ -154,20 +154,20 @@ func TestAllCases(t *testing.T) {
 				makeUnknownDeployment(),
 				makeService(),
 				makeReadyEndpoints(),
-				reconciletesting.NewInMemoryChannel(imcName, testNS),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS),
 			},
 			WantErr: false,
 			WantCreates: []runtime.Object{
-				makeChannelService(reconciletesting.NewInMemoryChannel(imcName, testNS)),
+				makeChannelService(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
 			},
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelDeploymentUnknown("DispatcherDeploymentUnknown", "The status of Dispatcher Deployment is Unknown: Deployment Unknown : Deployment Unknown"),
-					reconciletesting.WithInMemoryChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelEndpointsReady(),
-					reconciletesting.WithInMemoryChannelChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelAddress(channelServiceAddress)),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelDeploymentUnknownV1Beta1("DispatcherDeploymentUnknown", "The status of Dispatcher Deployment is Unknown: Deployment Unknown : Deployment Unknown"),
+					reconciletesting.WithInMemoryChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelEndpointsReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelAddressV1Beta1(channelServiceAddress)),
 			}},
 			WantEvents: []string{
 				Eventf(corev1.EventTypeNormal, "InMemoryChannelReconciled", `InMemoryChannel reconciled: "test-namespace/test-imc"`),
@@ -177,13 +177,13 @@ func TestAllCases(t *testing.T) {
 			Key:  imcKey,
 			Objects: []runtime.Object{
 				makeReadyDeployment(),
-				reconciletesting.NewInMemoryChannel(imcName, testNS),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS),
 			},
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelDeploymentReady(),
-					reconciletesting.WithInMemoryChannelServicetNotReady("DispatcherServiceDoesNotExist", "Dispatcher Service does not exist")),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelDeploymentReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelServicetNotReadyV1Beta1("DispatcherServiceDoesNotExist", "Dispatcher Service does not exist")),
 			}},
 			WantEvents: []string{
 				Eventf(corev1.EventTypeWarning, "DispatcherServiceFailed", `Reconciling dispatcher Service failed: service "imc-dispatcher" not found`),
@@ -194,15 +194,15 @@ func TestAllCases(t *testing.T) {
 			Objects: []runtime.Object{
 				makeReadyDeployment(),
 				makeService(),
-				reconciletesting.NewInMemoryChannel(imcName, testNS),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS),
 			},
 			WantErr: true,
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelDeploymentReady(),
-					reconciletesting.WithInMemoryChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelEndpointsNotReady("DispatcherEndpointsDoesNotExist", "Dispatcher Endpoints does not exist"),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelDeploymentReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelEndpointsNotReadyV1Beta1("DispatcherEndpointsDoesNotExist", "Dispatcher Endpoints does not exist"),
 				),
 			}},
 			WantEvents: []string{
@@ -215,15 +215,15 @@ func TestAllCases(t *testing.T) {
 				makeReadyDeployment(),
 				makeService(),
 				makeEmptyEndpoints(),
-				reconciletesting.NewInMemoryChannel(imcName, testNS),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS),
 			},
 			WantErr: true,
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelDeploymentReady(),
-					reconciletesting.WithInMemoryChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelEndpointsNotReady("DispatcherEndpointsNotReady", "There are no endpoints ready for Dispatcher service"),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelDeploymentReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelEndpointsNotReadyV1Beta1("DispatcherEndpointsNotReady", "There are no endpoints ready for Dispatcher service"),
 				),
 			}},
 			WantEvents: []string{
@@ -236,23 +236,23 @@ func TestAllCases(t *testing.T) {
 				makeReadyDeployment(),
 				makeService(),
 				makeReadyEndpoints(),
-				reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInMemoryChannelGeneration(imcGeneration)),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInMemoryChannelGenerationV1Beta1(imcGeneration)),
 			},
 			WantErr: false,
 			WantCreates: []runtime.Object{
-				makeChannelService(reconciletesting.NewInMemoryChannel(imcName, testNS)),
+				makeChannelService(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
 			},
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelDeploymentReady(),
-					reconciletesting.WithInMemoryChannelGeneration(imcGeneration),
-					reconciletesting.WithInMemoryChannelStatusObservedGeneration(imcGeneration),
-					reconciletesting.WithInMemoryChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelEndpointsReady(),
-					reconciletesting.WithInMemoryChannelChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelAddress(channelServiceAddress),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelDeploymentReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelGenerationV1Beta1(imcGeneration),
+					reconciletesting.WithInMemoryChannelStatusObservedGenerationV1Beta1(imcGeneration),
+					reconciletesting.WithInMemoryChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelEndpointsReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelAddressV1Beta1(channelServiceAddress),
 				),
 			}},
 			WantEvents: []string{
@@ -265,18 +265,18 @@ func TestAllCases(t *testing.T) {
 				makeReadyDeployment(),
 				makeService(),
 				makeReadyEndpoints(),
-				reconciletesting.NewInMemoryChannel(imcName, testNS),
-				makeChannelService(reconciletesting.NewInMemoryChannel(imcName, testNS)),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS),
+				makeChannelService(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
 			},
 			WantErr: false,
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelDeploymentReady(),
-					reconciletesting.WithInMemoryChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelEndpointsReady(),
-					reconciletesting.WithInMemoryChannelChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelAddress(channelServiceAddress),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelDeploymentReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelEndpointsReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelAddressV1Beta1(channelServiceAddress),
 				),
 			}},
 			WantEvents: []string{
@@ -289,17 +289,17 @@ func TestAllCases(t *testing.T) {
 				makeReadyDeployment(),
 				makeService(),
 				makeReadyEndpoints(),
-				reconciletesting.NewInMemoryChannel(imcName, testNS),
-				makeChannelServiceNotOwnedByUs(reconciletesting.NewInMemoryChannel(imcName, testNS)),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS),
+				makeChannelServiceNotOwnedByUs(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
 			},
 			WantErr: true,
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelDeploymentReady(),
-					reconciletesting.WithInMemoryChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelEndpointsReady(),
-					reconciletesting.WithInMemoryChannelChannelServiceNotReady("ChannelServiceFailed", "Channel Service failed: inmemorychannel: test-namespace/test-imc does not own Service: \"test-imc-kn-channel\""),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelDeploymentReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelEndpointsReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelChannelServiceNotReadyV1Beta1("ChannelServiceFailed", "Channel Service failed: inmemorychannel: test-namespace/test-imc does not own Service: \"test-imc-kn-channel\""),
 				),
 			}},
 			WantEvents: []string{
@@ -312,21 +312,21 @@ func TestAllCases(t *testing.T) {
 				makeReadyDeployment(),
 				makeService(),
 				makeReadyEndpoints(),
-				reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInMemoryChannelSubscribers(subscribers)),
-				makeChannelService(reconciletesting.NewInMemoryChannel(imcName, testNS)),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInMemoryChannelSubscribersV1Beta1(subscribers)),
+				makeChannelService(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
 			},
 			WantErr: false,
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelDeploymentReady(),
-					reconciletesting.WithInMemoryChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelEndpointsReady(),
-					reconciletesting.WithInMemoryChannelChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelSubscribers(subscribers),
-					reconciletesting.WithInMemoryChannelStatusSubscribers(subscriberStatuses),
-					reconciletesting.WithInMemoryChannelAddress(channelServiceAddress),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelDeploymentReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelEndpointsReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelSubscribersV1Beta1(subscribers),
+					reconciletesting.WithInMemoryChannelStatusSubscribersV1Beta1(subscriberStatuses),
+					reconciletesting.WithInMemoryChannelAddressV1Beta1(channelServiceAddress),
 				),
 			}},
 			WantEvents: []string{
@@ -339,23 +339,23 @@ func TestAllCases(t *testing.T) {
 				makeReadyDeployment(),
 				makeService(),
 				makeReadyEndpoints(),
-				reconciletesting.NewInMemoryChannel(imcName, testNS),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS),
 			},
 			WantErr: true,
 			WithReactors: []clientgotesting.ReactionFunc{
 				InduceFailure("create", "Services"),
 			},
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelDeploymentReady(),
-					reconciletesting.WithInMemoryChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelEndpointsReady(),
-					reconciletesting.WithInMemoryChannelChannelServiceNotReady("ChannelServiceFailed", "Channel Service failed: inducing failure for create services"),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelDeploymentReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelEndpointsReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelChannelServiceNotReadyV1Beta1("ChannelServiceFailed", "Channel Service failed: inducing failure for create services"),
 				),
 			}},
 			WantCreates: []runtime.Object{
-				makeChannelService(reconciletesting.NewInMemoryChannel(imcName, testNS)),
+				makeChannelService(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
 			},
 			WantEvents: []string{
 				Eventf(corev1.EventTypeWarning, "InternalError", "inducing failure for create services"),
@@ -368,7 +368,7 @@ func TestAllCases(t *testing.T) {
 		r := &Reconciler{
 			kubeClientSet:         fakekubeclient.Get(ctx),
 			systemNamespace:       testNS,
-			inmemorychannelLister: listers.GetInMemoryChannelLister(),
+			inmemorychannelLister: listers.GetV1Beta1InMemoryChannelLister(),
 			// TODO: FIx
 			inmemorychannelInformer: nil,
 			deploymentLister:        listers.GetDeploymentLister(),
@@ -376,7 +376,7 @@ func TestAllCases(t *testing.T) {
 			endpointsLister:         listers.GetEndpointsLister(),
 		}
 		return inmemorychannel.NewReconciler(ctx, logger,
-			fakeeventingclient.Get(ctx), listers.GetInMemoryChannelLister(),
+			fakeeventingclient.Get(ctx), listers.GetV1Beta1InMemoryChannelLister(),
 			controller.GetEventRecorder(ctx), r)
 	},
 		false,
@@ -391,26 +391,26 @@ func TestInNamespace(t *testing.T) {
 			Name: "Works, creates new service account, role binding, dispatcher deployment and service and channel",
 			Key:  imcKey,
 			Objects: []runtime.Object{
-				reconciletesting.NewInMemoryChannel(imcName, testNS, reconciletesting.WithInMemoryScopeAnnotation(eventing.ScopeNamespace)),
-				makeRoleBinding(systemNS, dispatcherName+"-"+testNS, "eventing-config-reader", reconciletesting.NewInMemoryChannel(imcName, testNS)),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS, reconciletesting.WithInMemoryScopeAnnotationV1Beta1(eventing.ScopeNamespace)),
+				makeRoleBinding(systemNS, dispatcherName+"-"+testNS, "eventing-config-reader", reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
 				makeReadyEndpoints(),
 			},
 			WantErr: false,
 			WantCreates: []runtime.Object{
-				makeServiceAccount(reconciletesting.NewInMemoryChannel(imcName, testNS)),
-				makeRoleBinding(testNS, dispatcherName, dispatcherName, reconciletesting.NewInMemoryChannel(imcName, testNS)),
-				makeDispatcherDeployment(reconciletesting.NewInMemoryChannel(imcName, testNS)),
+				makeServiceAccount(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
+				makeRoleBinding(testNS, dispatcherName, dispatcherName, reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
+				makeDispatcherDeployment(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
 				makeDispatcherService(testNS),
-				makeChannelService(reconciletesting.NewInMemoryChannel(imcName, testNS)),
+				makeChannelService(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
 			},
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInMemoryScopeAnnotation(eventing.ScopeNamespace),
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelEndpointsReady(),
-					reconciletesting.WithInMemoryChannelChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelAddress(channelServiceAddress),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInMemoryScopeAnnotationV1Beta1(eventing.ScopeNamespace),
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelEndpointsReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelAddressV1Beta1(channelServiceAddress),
 				),
 			}},
 			WantEvents: []string{
@@ -425,26 +425,26 @@ func TestInNamespace(t *testing.T) {
 			Name: "Works, existing service account, role binding, dispatcher deployment and service, new channel",
 			Key:  imcKey,
 			Objects: []runtime.Object{
-				reconciletesting.NewInMemoryChannel(imcName, testNS, reconciletesting.WithInMemoryScopeAnnotation(eventing.ScopeNamespace)),
-				makeServiceAccount(reconciletesting.NewInMemoryChannel(imcName, testNS)),
-				makeRoleBinding(testNS, dispatcherName, dispatcherName, reconciletesting.NewInMemoryChannel(imcName, testNS)),
-				makeRoleBinding(systemNS, dispatcherName+"-"+testNS, "eventing-config-reader", reconciletesting.NewInMemoryChannel(imcName, "knative-testing")),
-				makeDispatcherDeployment(reconciletesting.NewInMemoryChannel(imcName, testNS)),
+				reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS, reconciletesting.WithInMemoryScopeAnnotationV1Beta1(eventing.ScopeNamespace)),
+				makeServiceAccount(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
+				makeRoleBinding(testNS, dispatcherName, dispatcherName, reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
+				makeRoleBinding(systemNS, dispatcherName+"-"+testNS, "eventing-config-reader", reconciletesting.NewInMemoryChannelV1Beta1(imcName, "knative-testing")),
+				makeDispatcherDeployment(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
 				makeDispatcherService(testNS),
 				makeReadyEndpoints(),
 			},
 			WantErr: false,
 			WantCreates: []runtime.Object{
-				makeChannelService(reconciletesting.NewInMemoryChannel(imcName, testNS)),
+				makeChannelService(reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS)),
 			},
 			WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
-				Object: reconciletesting.NewInMemoryChannel(imcName, testNS,
-					reconciletesting.WithInMemoryScopeAnnotation(eventing.ScopeNamespace),
-					reconciletesting.WithInitInMemoryChannelConditions,
-					reconciletesting.WithInMemoryChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelEndpointsReady(),
-					reconciletesting.WithInMemoryChannelChannelServiceReady(),
-					reconciletesting.WithInMemoryChannelAddress(channelServiceAddress),
+				Object: reconciletesting.NewInMemoryChannelV1Beta1(imcName, testNS,
+					reconciletesting.WithInMemoryScopeAnnotationV1Beta1(eventing.ScopeNamespace),
+					reconciletesting.WithInitInMemoryChannelConditionsV1Beta1,
+					reconciletesting.WithInMemoryChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelEndpointsReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelChannelServiceReadyV1Beta1(),
+					reconciletesting.WithInMemoryChannelAddressV1Beta1(channelServiceAddress),
 				),
 			}},
 			WantEvents: []string{
@@ -459,7 +459,7 @@ func TestInNamespace(t *testing.T) {
 			kubeClientSet:         fakekubeclient.Get(ctx),
 			dispatcherImage:       imageName,
 			systemNamespace:       systemNS,
-			inmemorychannelLister: listers.GetInMemoryChannelLister(),
+			inmemorychannelLister: listers.GetV1Beta1InMemoryChannelLister(),
 			// TODO: FIx
 			inmemorychannelInformer: nil,
 			deploymentLister:        listers.GetDeploymentLister(),
@@ -469,7 +469,7 @@ func TestInNamespace(t *testing.T) {
 			roleBindingLister:       listers.GetRoleBindingLister(),
 		}
 		return inmemorychannel.NewReconciler(ctx, logger,
-			fakeeventingclient.Get(ctx), listers.GetInMemoryChannelLister(),
+			fakeeventingclient.Get(ctx), listers.GetV1Beta1InMemoryChannelLister(),
 			controller.GetEventRecorder(ctx), r)
 	},
 		false,
@@ -522,15 +522,15 @@ func makeService() *corev1.Service {
 	}
 }
 
-func makeServiceAccount(imc *v1alpha1.InMemoryChannel) *corev1.ServiceAccount {
+func makeServiceAccount(imc *v1beta1.InMemoryChannel) *corev1.ServiceAccount {
 	return resources.MakeServiceAccount(imc.Namespace, dispatcherName)
 }
 
-func makeRoleBinding(ns, name, clusterRoleName string, imc *v1alpha1.InMemoryChannel) *rbacv1.RoleBinding {
+func makeRoleBinding(ns, name, clusterRoleName string, imc *v1beta1.InMemoryChannel) *rbacv1.RoleBinding {
 	return resources.MakeRoleBinding(ns, name, makeServiceAccount(imc), clusterRoleName)
 }
 
-func makeDispatcherDeployment(imc *v1alpha1.InMemoryChannel) *appsv1.Deployment {
+func makeDispatcherDeployment(imc *v1beta1.InMemoryChannel) *appsv1.Deployment {
 	return resources.MakeDispatcher(resources.DispatcherArgs{
 		DispatcherName:      dispatcherName,
 		DispatcherNamespace: testNS,
@@ -543,7 +543,7 @@ func makeDispatcherService(ns string) *corev1.Service {
 	return resources.MakeDispatcherService(dispatcherName, ns)
 }
 
-func makeChannelService(imc *v1alpha1.InMemoryChannel) *corev1.Service {
+func makeChannelService(imc *v1beta1.InMemoryChannel) *corev1.Service {
 	return &corev1.Service{
 		TypeMeta: metav1.TypeMeta{
 			APIVersion: "v1",
@@ -566,7 +566,7 @@ func makeChannelService(imc *v1alpha1.InMemoryChannel) *corev1.Service {
 	}
 }
 
-func makeChannelServiceNotOwnedByUs(imc *v1alpha1.InMemoryChannel) *corev1.Service {
+func makeChannelServiceNotOwnedByUs(imc *v1beta1.InMemoryChannel) *corev1.Service {
 	return &corev1.Service{
 		TypeMeta: metav1.TypeMeta{
 			APIVersion: "v1",
